==> nui_core-0.0.127.tar.gz: lib/ui/nui_sharedpref_util.dart <==
import 'dart:convert';
import 'dart:developer';
import 'package:nui_core/code/nui_code_util.dart';
import 'package:nui_core/data/nui_data_util.dart';
import 'package:nui_core/data/nui_ent.dart';
import 'package:shared_preferences/shared_preferences.dart';

class NUISharedPref{

  static NUISharedPref _instance;

  SharedPreferences _pref;
  Future<SharedPreferences> _prefsInstance;
  Map<String, dynamic> _initials;

  NUISharedPref._builder(NUISharedPrefBuilder builder) : _initials = builder._initials;

  static NUISharedPref get(){
    if(_instance == null){
      throw Exception("NUISharedPref -> You have not initialized NUISharedPref with builder");
    }
    return _instance;
  }

  void _init() async {
    _prefsInstance = SharedPreferences.getInstance().then((value) => _pref = value);

    if(_initials != null) {
      for (String key in _initials.keys) {
        dynamic value = _initials[key];
        save(key, value);
      }
    }
  }

  dynamic quickGet(String key){
    return _pref.get(key);
  }
  Future<dynamic> getDynamic(String key) async{
    SharedPreferences pref = await _prefsInstance;
    return pref.get(key);
  }

  T quickGetObject<T extends NUIEnt>(String key, NUIEntMapper<T> entity){
    try{
      String value = _pref.getString(key);
      if(isNullOrEmpty(value)){
        return null;
      }
      return entity.toEntity(jsonDecode(value));
    }catch(e){
      log("NUISharedPref -> Failed to decode object ${entity.entityName()}");
      return null;
    }
  }
  Future<T> getObject<T extends NUIEnt>(String key, NUIEntMapper<T> entity) async{
    SharedPreferences pref = await _prefsInstance;
    try{
      String value = pref.getString(key);
      if(isNullOrEmpty(value)){
        return null;
      }
      return entity.toEntity(jsonDecode(value));
    }catch(e){
      log("NUISharedPref -> Failed to decode object ${entity.entityName()}");
      return null;
    }
  }

  int quickGetInt(String key, {int defValue: 0}){
    int value = _pref.getInt(key) ?? defValue;
    return value;
  }
  Future<int> getInt(String key, {int defValue: 0}) async{
    SharedPreferences pref = await _prefsInstance;
    int value = pref.getInt(key) ?? defValue;
    return value;
  }

  bool quickGetBool(String key, {bool defValue: false}){
    bool value = _pref.getBool(key) ?? defValue;
    return value;
  }
  Future<bool> getBool(String key, {bool defValue: false}) async{
    SharedPreferences pref = await _prefsInstance;
    bool value = pref.getBool(key) ?? defValue;
    return value;
  }

  double quickGetDouble(String key, {double defValue: 0.0}){
    double value = _pref.getDouble(key) ?? defValue;
    return value;
  }
  Future<double> getDouble(String key, {double defValue: 0.0}) async{
    SharedPreferences pref = await _prefsInstance;
    double value = pref.getDouble(key) ?? defValue;
    return value;
  }

  String quickGetString(String key, {String defValue: ""}){
    String value = _pref.getString(key) ?? defValue;
    return value;
  }
  Future<String> getString(String key, {String defValue: ""}) async{
    SharedPreferences pref = await _prefsInstance;
    String value = pref.getString(key) ?? defValue;
    return value;
  }

  List<String> quickGetStringList(String key, {List<String> defValue}){
    List<String> value = _pref.getStringList(key) ?? defValue ?? List();
    return value;
  }
  Future<List<String>> getStringList(String key, {List<String> defValue}) async{
    SharedPreferences pref = await _prefsInstance;
    List<String> value = pref.getStringList(key) ?? defValue ?? List();
    return value;
  }

  Future<bool> remove(String key) async{
    SharedPreferences pref = await _prefsInstance;
    return pref.remove(key);
  }

  Future<void> save(String key, dynamic value) async{
    SharedPreferences pref = await _prefsInstance;
    if(value is double){
      await pref.setDouble(key, value);
    }
    else if(value is int){
      await pref.setInt(key, value);
    }
    else if(value is String){
      await pref.setString(key, value);
    }
    else if(value is List<String>){
      await pref.setStringList(key, value);
    }
    else if(value is bool){
      await pref.setBool(key, value);
    }
    else if(value is NUIEnt){
      await pref.setString(key, jsonEncode(value));
    }
    else{
      throw new Exception("NUISharedPrefUtil -> value type of ${value.runtimeType} is not an acceptable value for shared preference");
    }
  }

}


class NUISharedPrefBuilder{
  Map<String, dynamic> _initials;

  NUISharedPrefBuilder setInitials(Map<String, dynamic> initials){
    this._initials = initials;
    return this;
  }

  Future<NUISharedPref> build() async {
    NUISharedPref sharedPref = NUISharedPref._builder(this);
    sharedPref._init();
    NUISharedPref._instance = sharedPref;

    logNUI("NUISharedPref", "Initialization successful");
    return sharedPref;
  }
}

==> nui_core-0.0.167.tar.gz: lib/ui/nui_sharedpref_util.dart <==
import 'dart:convert';
import 'dart:developer';
import 'package:nui_core/code/nui_code_util.dart';
import 'package:nui_core/data/nui_data_util.dart';
import 'package:nui_core/data/nui_ent.dart';
import 'package:shared_preferences/shared_preferences.dart';

class NUISharedPref{

  static NUISharedPref _instance;

  SharedPreferences _pref;
  Map<String, dynamic> _initials;

  NUISharedPref._builder(NUISharedPrefBuilder builder) : _initials = builder._initials;

  static NUISharedPref get(){
    if(_instance == null){
      throw Exception("NUISharedPref -> You have not initialized NUISharedPref with builder");
    }
    return _instance;
  }

  Future<bool> _init() async {
    _pref = await SharedPreferences.getInstance();

    if(_initials != null) {
      for (String key in _initials.keys) {
        dynamic value = _initials[key];
        save(key, value);
      }
    }

    return true;
  }

  dynamic quickGet(String key){
    return _pref.get(key);
  }
  Future<dynamic> getDynamic(String key) async{
    SharedPreferences pref = _pref;
    return pref.get(key);
  }

  T quickGetObject<T extends NUIEnt>(String key, NUIEntMapper<T> entity){
    try{
      String value = _pref.getString(key);
      if(isNullOrEmpty(value)){
        return null;
      }
      return entity.toEntity(jsonDecode(value));
    }catch(e){
      log("NUISharedPref -> Failed to decode object ${entity.entityName()}");
      return null;
    }
  }
  Future<T> getObject<T extends NUIEnt>(String key, NUIEntMapper<T> entity) async{
    SharedPreferences pref = _pref;
    try{
      String value = pref.getString(key);
      if(isNullOrEmpty(value)){
        return null;
      }
      return entity.toEntity(jsonDecode(value));
    }catch(e){
      log("NUISharedPref -> Failed to decode object ${entity.entityName()}");
      return null;
    }
  }

  int quickGetInt(String key, {int defValue: 0}){
    int value = _pref.getInt(key) ?? defValue;
    return value;
  }
  Future<int> getInt(String key, {int defValue: 0}) async{
    SharedPreferences pref = _pref;
    int value = pref.getInt(key) ?? defValue;
    return value;
  }

  bool quickGetBool(String key, {bool defValue: false}){
    bool value = _pref.getBool(key) ?? defValue;
    return value;
  }
  Future<bool> getBool(String key, {bool defValue: false}) async{
    SharedPreferences pref = _pref;
    bool value = pref.getBool(key) ?? defValue;
    return value;
  }

  double quickGetDouble(String key, {double defValue: 0.0}){
    double value = _pref.getDouble(key) ?? defValue;
    return value;
  }
  Future<double> getDouble(String key, {double defValue: 0.0}) async{
    SharedPreferences pref = _pref;
    double value = pref.getDouble(key) ?? defValue;
    return value;
  }

  String quickGetString(String key, {String defValue: ""}){
    String value = _pref.getString(key) ?? defValue;
    return value;
  }
  Future<String> getString(String key, {String defValue: ""}) async{
    SharedPreferences pref = _pref;
    String value = pref.getString(key) ?? defValue;
    return value;
  }

  List<String> quickGetStringList(String key, {List<String> defValue}){
    List<String> value = _pref.getStringList(key) ?? defValue ?? List();
    return value;
  }
  Future<List<String>> getStringList(String key, {List<String> defValue}) async{
    SharedPreferences pref = _pref;
    List<String> value = pref.getStringList(key) ?? defValue ?? List();
    return value;
  }

  Future<bool> remove(String key) async{
    SharedPreferences pref = _pref;
    return pref.remove(key);
  }

  Future<void> save(String key, dynamic value) async{
    SharedPreferences pref = _pref;
    if(value is double){
      await pref.setDouble(key, value);
    }
    else if(value is int){
      await pref.setInt(key, value);
    }
    else if(value is String){
      await pref.setString(key, value);
    }
    else if(value is List<String>){
      await pref.setStringList(key, value);
    }
    else if(value is bool){
      await pref.setBool(key, value);
    }
    else if(value is NUIEnt){
      await pref.setString(key, jsonEncode(value));
    }
    else{
      throw new Exception("NUISharedPrefUtil -> value type of ${value.runtimeType} is not an acceptable value for shared preference");
    }
  }

}


class NUISharedPrefBuilder{
  Map<String, dynamic> _initials;

  NUISharedPrefBuilder setInitials(Map<String, dynamic> initials){
    this._initials = initials;
    return this;
  }

  Future<NUISharedPref> build() async {
    NUISharedPref sharedPref = NUISharedPref._builder(this);
    await sharedPref._init();
    NUISharedPref._instance = sharedPref;

    logNUI("NUISharedPref", "Initialization successful");
    return sharedPref;
  }
}
